@@ -1,9 +1,9 @@
 # testing/requirements.py
-# Copyright (C) 2005-2021 the SQLAlchemy authors and contributors
+# Copyright (C) 2005-2022 the SQLAlchemy authors and contributors
 # <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
-# the MIT License: http://www.opensource.org/licenses/mit-license.php
+# the MIT License: https://www.opensource.org/licenses/mit-license.php
 
 """Global database feature support policy.
 
@@ -145,6 +145,12 @@ class SuiteRequirements(Requirements):
 
         return exclusions.open()
 
+    @property
+    def implicitly_named_constraints(self):
+        """target database must apply names to unnamed constraints."""
+
+        return exclusions.open()
+
     @property
     def subqueries(self):
         """Target database must support subqueries."""
@@ -222,9 +228,8 @@ class SuiteRequirements(Requirements):
 
     @property
     def standalone_binds(self):
-        """target database/driver supports bound parameters as column expressions
-        without being in the context of a typed column.
-
+        """target database/driver supports bound parameters as column
+        expressions without being in the context of a typed column.
         """
         return exclusions.closed()
 
@@ -494,7 +499,7 @@ class SuiteRequirements(Requirements):
     def foreign_key_constraint_name_reflection(self):
         """Target supports refleciton of FOREIGN KEY constraints and
         will return the name of the constraint that was used in the
-        "CONSTRANT <name> FOREIGN KEY" DDL.
+        "CONSTRAINT <name> FOREIGN KEY" DDL.
 
         MySQL prior to version 8 and MariaDB prior to version 10.5
         don't support this.
@@ -583,8 +588,16 @@ class SuiteRequirements(Requirements):
 
     @property
     def table_reflection(self):
+        """target database has general support for table reflection"""
         return exclusions.open()
 
+    @property
+    def reflect_tables_no_columns(self):
+        """target database supports creation and reflection of tables with no
+        columns, or at least tables that seem to have no columns."""
+
+        return exclusions.closed()
+
     @property
     def comment_reflection(self):
         return exclusions.closed()
@@ -650,6 +663,11 @@ class SuiteRequirements(Requirements):
         """target dialect supports listing of temporary table names"""
         return exclusions.closed()
 
+    @property
+    def has_temp_table(self):
+        """target dialect supports checking a single temp table name"""
+        return exclusions.closed()
+
     @property
     def temporary_tables(self):
         """target database supports temporary tables"""
@@ -739,6 +757,29 @@ class SuiteRequirements(Requirements):
 
         return exclusions.open()
 
+    @property
+    def datetime_timezone(self):
+        """target dialect supports representation of Python
+        datetime.datetime() with tzinfo with DateTime(timezone=True)."""
+
+        return exclusions.closed()
+
+    @property
+    def time_timezone(self):
+        """target dialect supports representation of Python
+        datetime.time() with tzinfo with Time(timezone=True)."""
+
+        return exclusions.closed()
+
+    @property
+    def datetime_implicit_bound(self):
+        """target dialect when given a datetime object will bind it such
+        that the database server knows the object is a datetime, and not
+        a plain string.
+
+        """
+        return exclusions.open()
+
     @property
     def datetime_microseconds(self):
         """target dialect supports representation of Python
@@ -753,6 +794,16 @@ class SuiteRequirements(Requirements):
         if TIMESTAMP is used."""
         return exclusions.closed()
 
+    @property
+    def timestamp_microseconds_implicit_bound(self):
+        """target dialect when given a datetime object which also includes
+        a microseconds portion when using the TIMESTAMP data type
+        will bind it such that the database server knows
+        the object is a datetime with microseconds, and not a plain string.
+
+        """
+        return self.timestamp_microseconds
+
     @property
     def datetime_historic(self):
         """target dialect supports representation of Python
@@ -851,7 +902,7 @@ class SuiteRequirements(Requirements):
 
             >>> testing.requirements.get_isolation_levels()
             {
-                "default": "READ_COMMITED",
+                "default": "READ_COMMITTED",
                 "supported": [
                     "SERIALIZABLE", "READ UNCOMMITTED",
                     "READ COMMITTED", "REPEATABLE READ",
@@ -966,6 +1017,12 @@ class SuiteRequirements(Requirements):
 
         return exclusions.closed()
 
+    @property
+    def infinity_floats(self):
+        """The Float type can persist and load float('inf'), float('-inf')."""
+
+        return exclusions.closed()
+
     @property
     def precision_generic_float_type(self):
         """target backend will return native floating point numbers with at
@@ -1220,6 +1277,10 @@ class SuiteRequirements(Requirements):
     def pep520(self):
         return self.python36
 
+    @property
+    def insert_order_dicts(self):
+        return self.python37
+
     @property
     def python36(self):
         return exclusions.skip_if(
@@ -1238,6 +1299,12 @@ class SuiteRequirements(Requirements):
     def dataclasses(self):
         return self.python37
 
+    @property
+    def python38(self):
+        return exclusions.only_if(
+            lambda: util.py38, "Python 3.8 or above required"
+        )
+
     @property
     def cpython(self):
         return exclusions.only_if(
@@ -1319,6 +1386,22 @@ class SuiteRequirements(Requirements):
 
         return exclusions.closed()
 
+    @property
+    def asyncio(self):
+        return self.greenlet
+
+    @property
+    def greenlet(self):
+        def go(config):
+            try:
+                import greenlet  # noqa: F401
+            except ImportError:
+                return False
+            else:
+                return True
+
+        return exclusions.only_if(go)
+
     @property
     def computed_columns(self):
         "Supports computed columns"
@@ -1418,9 +1501,23 @@ class SuiteRequirements(Requirements):
         """
         return exclusions.closed()
 
+    @property
+    def fetch_expression(self):
+        """backend supports fetch / offset with expression in them, like
+
+        SELECT * FROM some_table
+        OFFSET 1 + 1 ROWS FETCH FIRST 1 + 1 ROWS ONLY
+        """
+        return exclusions.closed()
+
     @property
     def autoincrement_without_sequence(self):
         """If autoincrement=True on a column does not require an explicit
         sequence. This should be false only for oracle.
         """
         return exclusions.open()
+
+    @property
+    def generic_classes(self):
+        "If X[Y] can be implemented with ``__class_getitem__``. py3.7+"
+        return exclusions.only_if(lambda: util.py37)
