@@ -5,6 +5,7 @@ from sqlalchemy import Column
 from sqlalchemy import func
 from sqlalchemy import inspect
 from sqlalchemy import Integer
+from sqlalchemy import literal_column
 from sqlalchemy import null
 from sqlalchemy import select
 from sqlalchemy import Table
@@ -26,6 +27,7 @@ from sqlalchemy.orm import relationship
 from sqlalchemy.orm import selectinload
 from sqlalchemy.orm import Session
 from sqlalchemy.orm import subqueryload
+from sqlalchemy.orm import synonym
 from sqlalchemy.orm import with_expression
 from sqlalchemy.orm import with_loader_criteria
 from sqlalchemy.orm import with_polymorphic
@@ -40,7 +42,6 @@ from sqlalchemy.testing.fixtures import fixture_session
 from test.orm import _fixtures
 from .inheritance import _poly_fixtures
 from .test_query import QueryTest
-from ..sql.test_compare import CacheKeyFixture
 
 
 def stmt_20(*elements):
@@ -50,7 +51,7 @@ def stmt_20(*elements):
     )
 
 
-class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
+class CacheKeyTest(fixtures.CacheKeyFixture, _fixtures.FixtureTest):
     run_setup_mappers = "once"
     run_inserts = None
     run_deletes = None
@@ -62,8 +63,19 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
     def test_mapper_and_aliased(self):
         User, Address, Keyword = self.classes("User", "Address", "Keyword")
 
+        addresses_table = self.tables.addresses
+
         self._run_cache_key_fixture(
-            lambda: (inspect(User), inspect(Address), inspect(aliased(User))),
+            lambda: (
+                inspect(User),
+                inspect(Address),
+                inspect(aliased(User)),
+                inspect(aliased(aliased(User, addresses_table))),
+                inspect(aliased(aliased(User), addresses_table.select())),
+                inspect(aliased(Address)),
+                inspect(aliased(Address, addresses_table.select())),
+                inspect(aliased(User, addresses_table.select())),
+            ),
             compare_values=True,
         )
 
@@ -387,6 +399,35 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
             compare_values=True,
         )
 
+    def test_synonyms(self, registry):
+        """test for issue discovered in #7394"""
+
+        @registry.mapped
+        class User2(object):
+            __table__ = self.tables.users
+
+            name_syn = synonym("name")
+
+        @registry.mapped
+        class Address2(object):
+            __table__ = self.tables.addresses
+
+            name_syn = synonym("email_address")
+
+        self._run_cache_key_fixture(
+            lambda: (
+                User2.id,
+                User2.name,
+                User2.name_syn,
+                Address2.name_syn,
+                Address2.email_address,
+                aliased(User2).name_syn,
+                aliased(User2, name="foo").name_syn,
+                aliased(User2, name="bar").name_syn,
+            ),
+            compare_values=True,
+        )
+
     def test_more_with_entities_sanity_checks(self):
         """test issue #6503"""
         User, Address, Keyword, Order, Item = self.classes(
@@ -544,7 +585,7 @@ class CacheKeyTest(CacheKeyFixture, _fixtures.FixtureTest):
         )
 
 
-class PolyCacheKeyTest(CacheKeyFixture, _poly_fixtures._Polymorphic):
+class PolyCacheKeyTest(fixtures.CacheKeyFixture, _poly_fixtures._Polymorphic):
     run_setup_mappers = "once"
     run_inserts = None
     run_deletes = None
@@ -576,6 +617,94 @@ class PolyCacheKeyTest(CacheKeyFixture, _poly_fixtures._Polymorphic):
             compare_values=True,
         )
 
+    def test_wpoly_cache_keys(self):
+        Person, Manager, Engineer, Boss = self.classes(
+            "Person", "Manager", "Engineer", "Boss"
+        )
+
+        meb_stmt = inspect(
+            with_polymorphic(Person, [Manager, Engineer, Boss])
+        ).selectable
+        me_stmt = inspect(
+            with_polymorphic(Person, [Manager, Engineer])
+        ).selectable
+
+        self._run_cache_key_fixture(
+            lambda: (
+                inspect(Person),
+                inspect(
+                    aliased(Person, me_stmt),
+                ),
+                inspect(
+                    aliased(Person, meb_stmt),
+                ),
+                inspect(
+                    with_polymorphic(Person, [Manager, Engineer]),
+                ),
+                # aliased=True is the same as flat=True for default selectable
+                inspect(
+                    with_polymorphic(
+                        Person, [Manager, Engineer], aliased=True
+                    ),
+                ),
+                inspect(
+                    with_polymorphic(Person, [Manager, Engineer], flat=True),
+                ),
+                inspect(
+                    with_polymorphic(
+                        Person, [Manager, Engineer], flat=True, innerjoin=True
+                    ),
+                ),
+                inspect(
+                    with_polymorphic(
+                        Person,
+                        [Manager, Engineer],
+                        flat=True,
+                        _use_mapper_path=True,
+                    ),
+                ),
+                inspect(
+                    with_polymorphic(
+                        Person,
+                        [Manager, Engineer],
+                        flat=True,
+                        adapt_on_names=True,
+                    ),
+                ),
+                inspect(
+                    with_polymorphic(
+                        Person, [Manager, Engineer], selectable=meb_stmt
+                    ),
+                ),
+                inspect(
+                    with_polymorphic(
+                        Person,
+                        [Manager, Engineer],
+                        selectable=meb_stmt,
+                        aliased=True,
+                    ),
+                ),
+                inspect(
+                    with_polymorphic(Person, [Manager, Engineer, Boss]),
+                ),
+                inspect(
+                    with_polymorphic(
+                        Person,
+                        [Manager, Engineer, Boss],
+                        polymorphic_on=literal_column("foo"),
+                    ),
+                ),
+                inspect(
+                    with_polymorphic(
+                        Person,
+                        [Manager, Engineer, Boss],
+                        polymorphic_on=literal_column("bar"),
+                    ),
+                ),
+            ),
+            compare_values=True,
+        )
+
     def test_wp_queries(self):
         Person, Manager, Engineer, Boss = self.classes(
             "Person", "Manager", "Engineer", "Boss"
